@@ -1,13 +1,13 @@
-use ades::cli::TimeUnit;
+use aoko::no_std::algebraic::sum::TimeUnit;
 use clap::Parser;
 
 /// A CLI tool for compressing and encrypting a file or directory. (tar, lzma, aes & des)
 
 #[derive(Parser)]
-#[clap(version = "0.1.4", author = "hzqd <hzqelf@yeah.net>")]
+#[clap(version = "0.1.6", author = "hzqd <hzqelf@yeah.net>")]
 pub struct Args {
     /// Specify the input file name
-    #[clap(short, long)]
+    #[clap()]
     pub input: String,
 
     /// Specify the AES key
